<?php

namespace Mbc\Slider\Http\Controllers\Api;

use App\Http\Controllers\Api\AdminController as BaseController;
use Mbc\Slider\Http\Requests\SliderRequest;
use Mbc\Slider\Interfaces\SliderRepositoryInterface;
use Mbc\Slider\Models\Slider;

/**
 * Admin API controller class.
 */
class SliderAdminController extends BaseController
{
    /**
     * Initialize slider controller.
     *
     * @param type SliderRepositoryInterface $slider
     *
     * @return type
     */
    public function __construct(SliderRepositoryInterface $slider)
    {
        $this->repository = $slider;
        parent::__construct();
    }

    /**
     * Display a list of slider.
     *
     * @return json
     */
    public function index(SliderRequest $request)
    {
        $sliders  = $this->repository
            ->setPresenter('\\Mbc\\Slider\\Repositories\\Presenter\\SliderListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $sliders['code'] = 2000;
        return response()->json($sliders) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display slider.
     *
     * @param Request $request
     * @param Model   Slider
     *
     * @return Json
     */
    public function show(SliderRequest $request, Slider $slider)
    {
        $slider         = $slider->presenter();
        $slider['code'] = 2001;
        return response()->json($slider)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new slider.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(SliderRequest $request, Slider $slider)
    {
        $slider         = $slider->presenter();
        $slider['code'] = 2002;
        return response()->json($slider)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new slider.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(SliderRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $slider          = $this->repository->create($attributes);
            $slider          = $slider->presenter();
            $slider['code']  = 2004;

            return response()->json($slider)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }
    }

    /**
     * Show slider for editing.
     *
     * @param Request $request
     * @param Model   $slider
     *
     * @return json
     */
    public function edit(SliderRequest $request, Slider $slider)
    {
        $slider         = $slider->presenter();
        $slider['code'] = 2003;
        return response()-> json($slider)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the slider.
     *
     * @param Request $request
     * @param Model   $slider
     *
     * @return json
     */
    public function update(SliderRequest $request, Slider $slider)
    {
        try {

            $attributes = $request->all();

            $slider->update($attributes);
            $slider         = $slider->presenter();
            $slider['code'] = 2005;

            return response()->json($slider)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the slider.
     *
     * @param Request $request
     * @param Model   $slider
     *
     * @return json
     */
    public function destroy(SliderRequest $request, Slider $slider)
    {
        try {
            $t = $slider->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('slider::slider.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
