<?php

namespace Mbc\Slider\Http\Controllers;
use Litepie\Slider\Http\Requests\SliderRequest;
use Litepie\Slider\Models\Slider;

trait SliderWorkflow {
	
    /**
     * Workflow controller function for slider.
     *
     * @param Model   $slider
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(SliderRequest $request, Slider $slider, $step)
    {

        try {

            $slider->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('slider::slider.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/slider/slider/' . $slider->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/slider/slider/' . $slider->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for slider.
     *
     * @param Model   $slider
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Slider $slider, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $slider->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('slider::slider.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('slider::admin.slider.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('slider::admin.slider.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('slider::admin.slider.message', $data)->render();

        }

    }
}