<?php

namespace Mbc\Slider\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Mbc\Slider\Models\Slider;

class SliderAction
{
    /**
     * Perform the complete action.
     *
     * @param Slider $slider
     *
     * @return Slider
     */
    public function complete(Slider $slider)
    {
        try {
            $slider->status = 'complete';
            return $slider->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Slider $slider
     *
     * @return Slider
     */public function verify(Slider $slider)
    {
        try {
            $slider->status = 'verify';
            return $slider->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Slider $slider
     *
     * @return Slider
     */public function approve(Slider $slider)
    {
        try {
            $slider->status = 'approve';
            return $slider->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Slider $slider
     *
     * @return Slider
     */public function publish(Slider $slider)
    {
        try {
            $slider->status = 'publish';
            return $slider->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Slider $slider
     *
     * @return Slider
     */
    public function archive(Slider $slider)
    {
        try {
            $slider->status = 'archive';
            return $slider->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Slider $slider
     *
     * @return Slider
     */
    public function unpublish(Slider $slider)
    {
        try {
            $slider->status = 'unpublish';
            return $slider->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
