<?php

namespace Mbc\Slider\Workflow;

use Mbc\Slider\Models\Slider;
use Validator;

class SliderValidator
{

    /**
     * Determine if the given slider is valid for complete status.
     *
     * @param Slider $slider
     *
     * @return bool / Validator
     */
    public function complete(Slider $slider)
    {
        return Validator::make($slider->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given slider is valid for verify status.
     *
     * @param Slider $slider
     *
     * @return bool / Validator
     */
    public function verify(Slider $slider)
    {
        return Validator::make($slider->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given slider is valid for approve status.
     *
     * @param Slider $slider
     *
     * @return bool / Validator
     */
    public function approve(Slider $slider)
    {
        return Validator::make($slider->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given slider is valid for publish status.
     *
     * @param Slider $slider
     *
     * @return bool / Validator
     */
    public function publish(Slider $slider)
    {
        return Validator::make($slider->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given slider is valid for archive status.
     *
     * @param Slider $slider
     *
     * @return bool / Validator
     */
    public function archive(Slider $slider)
    {
        return Validator::make($slider->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given slider is valid for unpublish status.
     *
     * @param Slider $slider
     *
     * @return bool / Validator
     */
    public function unpublish(Slider $slider)
    {
        return Validator::make($slider->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
